==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/geode-core/src/test/java/org/apache/geode/internal/ra/spi/JCALocalTransactionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.ra.spi;

import static org.mockito.Mockito.doAnswer;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import javax.resource.ResourceException;

import org.junit.Before;
import org.junit.Test;

import org.apache.geode.internal.cache.GemFireCacheImpl;
import org.apache.geode.internal.cache.TXManagerImpl;
import org.apache.geode.internal.cache.TXStateProxy;
import org.apache.geode.test.fake.Fakes;

public class JCALocalTransactionTest {

  private GemFireCacheImpl cache;

  private TXManagerImpl transactionManager;

  @Before
  public void setUp() throws Exception {
    this.cache = Fakes.cache();
    this.transactionManager = mock(TXManagerImpl.class);
  }

  @Test
  public void testCallingBeginDoesBeginTransaction() throws ResourceException {
    // Create JCALocalTransaction
    JCALocalTransaction jcaTransaction =
        new JCALocalTransaction(this.cache, this.transactionManager);

    // Once TXManagerImpl begin is called, add when/thenReturn to return the TXStateProxy
    doAnswer(invocation -> {
      when(this.transactionManager.getTXState()).thenReturn(mock(TXStateProxy.class));
      return null;
    }).when(this.transactionManager).begin();

    // Begin the transaction
    jcaTransaction.begin();

    // Verify the TXManagerImpl begins a transaction
    verify(this.transactionManager, times(1)).begin();
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/test/java/org/apache/geode/internal/ra/spi/JCALocalTransactionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.ra.spi;

import static org.mockito.Mockito.doAnswer;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import javax.resource.ResourceException;

import org.junit.Before;
import org.junit.Test;

import org.apache.geode.internal.cache.GemFireCacheImpl;
import org.apache.geode.internal.cache.TXManagerImpl;
import org.apache.geode.internal.cache.TXStateProxy;
import org.apache.geode.test.fake.Fakes;

public class JCALocalTransactionTest {

  private GemFireCacheImpl cache;

  private TXManagerImpl transactionManager;

  @Before
  public void setUp() throws Exception {
    cache = Fakes.cache();
    transactionManager = mock(TXManagerImpl.class);
  }

  @Test
  public void testCallingBeginDoesBeginTransaction() throws ResourceException {
    // Create JCALocalTransaction
    JCALocalTransaction jcaTransaction =
        new JCALocalTransaction(cache, transactionManager);

    // Once TXManagerImpl begin is called, add when/thenReturn to return the TXStateProxy
    doAnswer(invocation -> {
      when(transactionManager.getTXState()).thenReturn(mock(TXStateProxy.class));
      return null;
    }).when(transactionManager).begin();

    // Begin the transaction
    jcaTransaction.begin();

    // Verify the TXManagerImpl begins a transaction
    verify(transactionManager, times(1)).begin();
  }
}
